@@ -1,10 +1,9 @@
 package ExtUtils::CBuilder::Platform::Unix;
-
+$ExtUtils::CBuilder::Platform::Unix::VERSION = '0.280218';
 use strict;
 use ExtUtils::CBuilder::Base;
 
-use vars qw($VERSION @ISA);
-$VERSION = '0.2802';
+use vars qw(@ISA);
 @ISA = qw(ExtUtils::CBuilder::Base);
 
 sub link_executable {
