@@ -1,13 +1,13 @@
 package ExtUtils::CBuilder::Platform::VMS;
-
+$ExtUtils::CBuilder::Platform::VMS::VERSION = '0.280218';
 use strict;
 use ExtUtils::CBuilder::Base;
 
-use vars qw($VERSION @ISA);
-$VERSION = '0.280202';
+use vars qw(@ISA);
 @ISA = qw(ExtUtils::CBuilder::Base);
 
 use File::Spec::Functions qw(catfile catdir);
+use Config;
 
 # We do prelink, but don't want the parent to redo it.
 
@@ -47,6 +47,20 @@ sub arg_include_dirs {
   return ('/include=(' . join(',', @dirs) . ')');
 }
 
+# We override the compile method because we consume the includes and defines
+# parts of ccflags in the process of compiling but don't save those parts
+# anywhere, so $self->{config}{ccflags} needs to be reset for each compile
+# operation.  
+
+sub compile {
+  my ($self, %args) = @_;
+
+  $self->{config}{ccflags} = $Config{ccflags};
+  $self->{config}{ccflags} = $ENV{CFLAGS} if defined $ENV{CFLAGS};
+
+  return $self->SUPER::compile(%args);
+}
+
 sub _do_link {
   my ($self, $type, %args) = @_;
   
@@ -103,22 +117,6 @@ sub arg_share_object_file {
   return ("$self->{config}{lddlflags}=$file");
 }
 
-
-sub lib_file {
-  my ($self, $dl_file) = @_;
-  $dl_file =~ s/\.[^.]+$//;
-  $dl_file =~ tr/"//d;
-  $dl_file = $dl_file .= '.' . $self->{config}{dlext};
-
-  # Need to create with the same name as DynaLoader will load with.
-  if (defined &DynaLoader::mod2fname) {
-    my ($dev,$dir,$file) = File::Spec->splitpath($dl_file);
-    $file = DynaLoader::mod2fname([$file]);
-    $dl_file = File::Spec->catpath($dev,$dir,$file);
-  }
-  return $dl_file;
-}
-
 # The following is reproduced almost verbatim from ExtUtils::Liblist::Kid::_vms_ext.
 # We can't just call that because it's tied up with the MakeMaker object hierarchy.
 
